import escapeId from './escape-id';
import escape from './escape';
import { Client as Postgres } from 'pg';
import fullJitter from './full-jitter';
import executeStatement from './execute-statement';
import connect from './connect';

const configure = (pool, config) => {
  var _config$eventsTableNa, _config$snapshotsTabl, _config$secretsTableN, _config$subscribersTa;

  const createGetConnectPromise = () => {
    let p;
    return () => {
      if (p === undefined) {
        p = connect(pool);
      }

      return p;
    };
  };

  const props = {
    databaseName: config.databaseName,
    eventsTableName: (_config$eventsTableNa = config.eventsTableName) !== null && _config$eventsTableNa !== void 0 ? _config$eventsTableNa : 'events',
    snapshotsTableName: (_config$snapshotsTabl = config.snapshotsTableName) !== null && _config$snapshotsTabl !== void 0 ? _config$snapshotsTabl : 'snapshots',
    secretsTableName: (_config$secretsTableN = config.secretsTableName) !== null && _config$secretsTableN !== void 0 ? _config$secretsTableN : 'secrets',
    subscribersTableName: (_config$subscribersTa = config.subscribersTableName) !== null && _config$subscribersTa !== void 0 ? _config$subscribersTa : 'subscribers',
    connectionOptions: {
      user: config.user,
      database: config.database,
      port: config.port,
      host: config.host,
      password: config.password
    },
    Postgres,
    fullJitter,
    escape,
    escapeId,
    executeStatement: executeStatement.bind(null, pool),
    createGetConnectPromise,
    getConnectPromise: createGetConnectPromise(),
    extraConnections: new Set(),
    eventLoaders: new Set()
  };
  Object.assign(pool, props);
};

export default configure;
//# sourceMappingURL=configure.js.map