"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _constants = require("./constants");

const createLoadQuery = ({
  escapeId,
  escape,
  eventsTableName,
  databaseName
}, {
  eventTypes,
  aggregateIds,
  cursor,
  limit
}) => {
  const vectorConditions = (0, _eventstoreBase.cursorToThreadArray)(cursor);

  const injectString = value => `${escape(value)}`;

  const injectNumber = value => `${+value}`;

  const queryConditions = ['1 = 1'];

  if (eventTypes != null) {
    if (eventTypes.length === 0) {
      return null;
    }

    queryConditions.push(`"type" IN (${eventTypes.map(injectString)})`);
  }

  if (aggregateIds != null) {
    if (aggregateIds.length === 0) {
      return null;
    }

    queryConditions.push(`"aggregateId" IN (${aggregateIds.map(injectString)})`);
  }

  const resultQueryCondition = queryConditions.join(' AND ');
  const databaseNameAsId = escapeId(databaseName);
  const eventsTableAsId = escapeId(eventsTableName);

  if (limit !== undefined) {
    return [`SELECT "unitedEvents".* FROM (
        ${vectorConditions.map((threadCounter, threadId) => `(${[`SELECT * FROM ${databaseNameAsId}.${eventsTableAsId}`, `WHERE (${resultQueryCondition}) AND "threadId" = ${threadId} AND "threadCounter" >= ${threadCounter}::${_constants.INT8_SQL_TYPE}`, `LIMIT ${limit}`].join(' ')})`).join(' UNION ALL \n')}
        ) "unitedEvents"`, `ORDER BY "unitedEvents"."timestamp" ASC, "unitedEvents"."threadCounter" ASC, "unitedEvents"."threadId" ASC`, `LIMIT ${+limit}`].join('\n');
  } else {
    const resultVectorConditions = `${vectorConditions.map((threadCounter, threadId) => `"threadId" = ${injectNumber(threadId)} AND "threadCounter" >= ${threadCounter}::${_constants.INT8_SQL_TYPE} `).join(' OR ')}`;
    return [`SELECT * FROM ${databaseNameAsId}.${eventsTableAsId}`, `WHERE (${resultVectorConditions}) AND (${resultQueryCondition})`, `ORDER BY "timestamp" ASC, "threadCounter" ASC, "threadId" ASC`].join('\n');
  }
};

var _default = createLoadQuery;
exports.default = _default;
//# sourceMappingURL=create-load-query.js.map