"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

const getLatestEvent = async ({
  executeStatement,
  escapeId,
  escape,
  eventsTableName,
  databaseName,
  shapeEvent
}, filter) => {
  const {
    eventTypes,
    aggregateIds
  } = filter;

  const injectString = value => `${escape(value)}`;

  const databaseNameAsId = escapeId(databaseName);
  const eventsTableNameAsId = escapeId(eventsTableName);
  const queryConditions = [];

  if (eventTypes != null) {
    if (eventTypes.length === 0) {
      return null;
    }

    queryConditions.push(`"type" IN (${eventTypes.map(injectString)})`);
  }

  if (aggregateIds != null) {
    if (aggregateIds.length === 0) {
      return null;
    }

    queryConditions.push(`"aggregateId" IN (${aggregateIds.map(injectString)})`);
  }

  const resultQueryCondition = queryConditions.length > 0 ? `WHERE ${queryConditions.join(' AND ')}` : '';
  const rows = await executeStatement(`SELECT * FROM ${databaseNameAsId}.${eventsTableNameAsId}
    ${resultQueryCondition}
    ORDER BY "timestamp" DESC
    OFFSET 0
    LIMIT 1`);

  if (rows.length === 0) {
    return null;
  }

  return shapeEvent(rows[0]);
};

var _default = getLatestEvent;
exports.default = _default;
//# sourceMappingURL=get-latest-event.js.map