"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

const resetReplication = async pool => {
  const {
    executeStatement,
    databaseName,
    eventsTableName,
    secretsTableName,
    escapeId,
    escape
  } = pool;
  const databaseNameAsId = escapeId(databaseName);
  const eventsTableNameAsId = escapeId(eventsTableName);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const replicationStateTableName = `${eventsTableName}-replication-state`;
  const replicationStateTableNameAsId = escapeId(replicationStateTableName);
  const threadsTableAsId = escapeId(`${eventsTableName}-threads`);
  const notStarted = 'notStarted';
  await executeStatement(`
  BEGIN WORK;
  LOCK ${databaseNameAsId}.${replicationStateTableNameAsId} IN ACCESS EXCLUSIVE MODE;
  TRUNCATE ${databaseNameAsId}.${eventsTableNameAsId};
  TRUNCATE ${databaseNameAsId}.${secretsTableNameAsId};
  UPDATE ${databaseNameAsId}.${threadsTableAsId} SET "threadCounter" = 0;
  UPDATE ${databaseNameAsId}.${replicationStateTableNameAsId} SET
      "Status" = ${escape(notStarted)},
      "StatusData" = NULL,
      "Iterator" = NULL,
      "SuccessEvent" = NULL,
      "LockExpirationTime" = 0,
      "LockId" = NULL;
  COMMIT WORK;`);
};

var _default = resetReplication;
exports.default = _default;
//# sourceMappingURL=reset-replication.js.map