"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _initReplicationStateTable = _interopRequireDefault(require("./init-replication-state-table"));

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setReplicationLock = async (pool, lockId, lockDuration) => {
  const {
    executeStatement,
    escapeId,
    databaseName
  } = pool;
  const replicationStateTableName = await (0, _initReplicationStateTable.default)(pool);
  const databaseNameAsId = escapeId(databaseName);

  if (lockDuration <= 0) {
    const rows = await executeStatement(`UPDATE ${databaseNameAsId}.${escapeId(replicationStateTableName)} 
    SET
      "LockExpirationTime" = 0,
      "LockId" = NULL
    WHERE "LockId" = ${pool.escape(lockId)}
    RETURNING "LockExpirationTime", "LockId"`);
    return rows.length !== 0;
  } else {
    const rows = await executeStatement(`UPDATE ${databaseNameAsId}.${escapeId(replicationStateTableName)} 
    SET
      "LockExpirationTime" = CAST(extract(epoch from clock_timestamp()) * 1000 AS ${_constants.LONG_NUMBER_SQL_TYPE}) + ${+lockDuration},
      "LockId" = ${pool.escape(lockId)}
    WHERE "LockExpirationTime" < CAST(extract(epoch from clock_timestamp()) * 1000 AS ${_constants.LONG_NUMBER_SQL_TYPE})
    RETURNING "LockExpirationTime", "LockId"`);
    return rows.length !== 0;
  }
};

var _default = setReplicationLock;
exports.default = _default;
//# sourceMappingURL=set-replication-lock.js.map