"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

var _initReplicationStateTable = _interopRequireDefault(require("./init-replication-state-table"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setReplicationStatus = async (pool, lockId, {
  statusAndData,
  lastEvent,
  iterator
}) => {
  const {
    executeStatement,
    escapeId,
    escape,
    databaseName
  } = pool;
  const replicationStateTableName = await (0, _initReplicationStateTable.default)(pool);
  const databaseNameAsId = escapeId(databaseName);
  const rows = await executeStatement(`UPDATE ${databaseNameAsId}.${escapeId(replicationStateTableName)} 
    SET
      "Status" = ${escape(statusAndData.status)},
      "StatusData" = ${statusAndData.data != null ? escape(JSON.stringify(statusAndData.data)) : 'NULL'}
      ${lastEvent != null ? `, "SuccessEvent" = ${escape(JSON.stringify(lastEvent))}` : ``}
      ${iterator !== undefined ? `, "Iterator" = ${iterator != null ? escape(JSON.stringify(iterator)) : 'NULL'}` : ``}
      WHERE "LockId" = ${pool.escape(lockId)}
      RETURNING "Status", "StatusData", "Iterator", "IsPaused", "SuccessEvent", 
    ("LockExpirationTime" > (CAST(extract(epoch from clock_timestamp()) * 1000 AS ${_constants.LONG_NUMBER_SQL_TYPE}))) as "Locked", "LockId"`);

  if (rows.length === 1) {
    const row = rows[0];
    let lastEvent = null;

    if (row.SuccessEvent != null) {
      lastEvent = row.SuccessEvent;
    }

    return {
      statusAndData: {
        status: row.Status,
        data: row.StatusData
      },
      paused: row.IsPaused,
      iterator: row.Iterator,
      successEvent: lastEvent,
      locked: row.Locked,
      lockId: row.LockId
    };
  } else {
    return null;
  }
};

var _default = setReplicationStatus;
exports.default = _default;
//# sourceMappingURL=set-replication-status.js.map